from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.http_service_record import HttpServiceRecord
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    name: Union[Unset, None, str] = "",
    api: Union[Unset, None, str] = "",
    engine: Union[Unset, None, str] = "",
    function: Union[Unset, None, str] = "",
    language: Union[Unset, None, str] = "",
    type: Union[Unset, None, str] = "",
    nature: Union[Unset, None, str] = "",
    version: Union[Unset, None, str] = "",
    term_importer: Union[Unset, None, str] = "",
    annotator: Union[Unset, None, str] = "",
    processor: Union[Unset, None, str] = "",
    formatter: Union[Unset, None, str] = "",
    converter: Union[Unset, None, str] = "",
    segmenter: Union[Unset, None, str] = "",
    language_guesser: Union[Unset, None, str] = "",
) -> Dict[str, Any]:
    url = "{}/services".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["name"] = name

    params["api"] = api

    params["engine"] = engine

    params["function"] = function

    params["language"] = language

    params["type"] = type

    params["nature"] = nature

    params["version"] = version

    params["termImporter"] = term_importer

    params["annotator"] = annotator

    params["processor"] = processor

    params["formatter"] = formatter

    params["converter"] = converter

    params["segmenter"] = segmenter

    params["languageGuesser"] = language_guesser

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["HttpServiceRecord"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_http_service_record_array_item_data in _response_200:
            componentsschemas_http_service_record_array_item = HttpServiceRecord.from_dict(
                componentsschemas_http_service_record_array_item_data
            )

            response_200.append(componentsschemas_http_service_record_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[List["HttpServiceRecord"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    name: Union[Unset, None, str] = "",
    api: Union[Unset, None, str] = "",
    engine: Union[Unset, None, str] = "",
    function: Union[Unset, None, str] = "",
    language: Union[Unset, None, str] = "",
    type: Union[Unset, None, str] = "",
    nature: Union[Unset, None, str] = "",
    version: Union[Unset, None, str] = "",
    term_importer: Union[Unset, None, str] = "",
    annotator: Union[Unset, None, str] = "",
    processor: Union[Unset, None, str] = "",
    formatter: Union[Unset, None, str] = "",
    converter: Union[Unset, None, str] = "",
    segmenter: Union[Unset, None, str] = "",
    language_guesser: Union[Unset, None, str] = "",
) -> Response[List["HttpServiceRecord"]]:
    """Filter the list of available services

    Args:
        name (Union[Unset, None, str]):  Default: ''.
        api (Union[Unset, None, str]):  Default: ''.
        engine (Union[Unset, None, str]):  Default: ''.
        function (Union[Unset, None, str]):  Default: ''.
        language (Union[Unset, None, str]):  Default: ''.
        type (Union[Unset, None, str]):  Default: ''.
        nature (Union[Unset, None, str]):  Default: ''.
        version (Union[Unset, None, str]):  Default: ''.
        term_importer (Union[Unset, None, str]):  Default: ''.
        annotator (Union[Unset, None, str]):  Default: ''.
        processor (Union[Unset, None, str]):  Default: ''.
        formatter (Union[Unset, None, str]):  Default: ''.
        converter (Union[Unset, None, str]):  Default: ''.
        segmenter (Union[Unset, None, str]):  Default: ''.
        language_guesser (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['HttpServiceRecord']]
    """

    kwargs = _get_kwargs(
        client=client,
        name=name,
        api=api,
        engine=engine,
        function=function,
        language=language,
        type=type,
        nature=nature,
        version=version,
        term_importer=term_importer,
        annotator=annotator,
        processor=processor,
        formatter=formatter,
        converter=converter,
        segmenter=segmenter,
        language_guesser=language_guesser,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    name: Union[Unset, None, str] = "",
    api: Union[Unset, None, str] = "",
    engine: Union[Unset, None, str] = "",
    function: Union[Unset, None, str] = "",
    language: Union[Unset, None, str] = "",
    type: Union[Unset, None, str] = "",
    nature: Union[Unset, None, str] = "",
    version: Union[Unset, None, str] = "",
    term_importer: Union[Unset, None, str] = "",
    annotator: Union[Unset, None, str] = "",
    processor: Union[Unset, None, str] = "",
    formatter: Union[Unset, None, str] = "",
    converter: Union[Unset, None, str] = "",
    segmenter: Union[Unset, None, str] = "",
    language_guesser: Union[Unset, None, str] = "",
) -> Optional[List["HttpServiceRecord"]]:
    """Filter the list of available services

    Args:
        name (Union[Unset, None, str]):  Default: ''.
        api (Union[Unset, None, str]):  Default: ''.
        engine (Union[Unset, None, str]):  Default: ''.
        function (Union[Unset, None, str]):  Default: ''.
        language (Union[Unset, None, str]):  Default: ''.
        type (Union[Unset, None, str]):  Default: ''.
        nature (Union[Unset, None, str]):  Default: ''.
        version (Union[Unset, None, str]):  Default: ''.
        term_importer (Union[Unset, None, str]):  Default: ''.
        annotator (Union[Unset, None, str]):  Default: ''.
        processor (Union[Unset, None, str]):  Default: ''.
        formatter (Union[Unset, None, str]):  Default: ''.
        converter (Union[Unset, None, str]):  Default: ''.
        segmenter (Union[Unset, None, str]):  Default: ''.
        language_guesser (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['HttpServiceRecord']]
    """

    return sync_detailed(
        client=client,
        name=name,
        api=api,
        engine=engine,
        function=function,
        language=language,
        type=type,
        nature=nature,
        version=version,
        term_importer=term_importer,
        annotator=annotator,
        processor=processor,
        formatter=formatter,
        converter=converter,
        segmenter=segmenter,
        language_guesser=language_guesser,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    name: Union[Unset, None, str] = "",
    api: Union[Unset, None, str] = "",
    engine: Union[Unset, None, str] = "",
    function: Union[Unset, None, str] = "",
    language: Union[Unset, None, str] = "",
    type: Union[Unset, None, str] = "",
    nature: Union[Unset, None, str] = "",
    version: Union[Unset, None, str] = "",
    term_importer: Union[Unset, None, str] = "",
    annotator: Union[Unset, None, str] = "",
    processor: Union[Unset, None, str] = "",
    formatter: Union[Unset, None, str] = "",
    converter: Union[Unset, None, str] = "",
    segmenter: Union[Unset, None, str] = "",
    language_guesser: Union[Unset, None, str] = "",
) -> Response[List["HttpServiceRecord"]]:
    """Filter the list of available services

    Args:
        name (Union[Unset, None, str]):  Default: ''.
        api (Union[Unset, None, str]):  Default: ''.
        engine (Union[Unset, None, str]):  Default: ''.
        function (Union[Unset, None, str]):  Default: ''.
        language (Union[Unset, None, str]):  Default: ''.
        type (Union[Unset, None, str]):  Default: ''.
        nature (Union[Unset, None, str]):  Default: ''.
        version (Union[Unset, None, str]):  Default: ''.
        term_importer (Union[Unset, None, str]):  Default: ''.
        annotator (Union[Unset, None, str]):  Default: ''.
        processor (Union[Unset, None, str]):  Default: ''.
        formatter (Union[Unset, None, str]):  Default: ''.
        converter (Union[Unset, None, str]):  Default: ''.
        segmenter (Union[Unset, None, str]):  Default: ''.
        language_guesser (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['HttpServiceRecord']]
    """

    kwargs = _get_kwargs(
        client=client,
        name=name,
        api=api,
        engine=engine,
        function=function,
        language=language,
        type=type,
        nature=nature,
        version=version,
        term_importer=term_importer,
        annotator=annotator,
        processor=processor,
        formatter=formatter,
        converter=converter,
        segmenter=segmenter,
        language_guesser=language_guesser,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    name: Union[Unset, None, str] = "",
    api: Union[Unset, None, str] = "",
    engine: Union[Unset, None, str] = "",
    function: Union[Unset, None, str] = "",
    language: Union[Unset, None, str] = "",
    type: Union[Unset, None, str] = "",
    nature: Union[Unset, None, str] = "",
    version: Union[Unset, None, str] = "",
    term_importer: Union[Unset, None, str] = "",
    annotator: Union[Unset, None, str] = "",
    processor: Union[Unset, None, str] = "",
    formatter: Union[Unset, None, str] = "",
    converter: Union[Unset, None, str] = "",
    segmenter: Union[Unset, None, str] = "",
    language_guesser: Union[Unset, None, str] = "",
) -> Optional[List["HttpServiceRecord"]]:
    """Filter the list of available services

    Args:
        name (Union[Unset, None, str]):  Default: ''.
        api (Union[Unset, None, str]):  Default: ''.
        engine (Union[Unset, None, str]):  Default: ''.
        function (Union[Unset, None, str]):  Default: ''.
        language (Union[Unset, None, str]):  Default: ''.
        type (Union[Unset, None, str]):  Default: ''.
        nature (Union[Unset, None, str]):  Default: ''.
        version (Union[Unset, None, str]):  Default: ''.
        term_importer (Union[Unset, None, str]):  Default: ''.
        annotator (Union[Unset, None, str]):  Default: ''.
        processor (Union[Unset, None, str]):  Default: ''.
        formatter (Union[Unset, None, str]):  Default: ''.
        converter (Union[Unset, None, str]):  Default: ''.
        segmenter (Union[Unset, None, str]):  Default: ''.
        language_guesser (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['HttpServiceRecord']]
    """

    return (
        await asyncio_detailed(
            client=client,
            name=name,
            api=api,
            engine=engine,
            function=function,
            language=language,
            type=type,
            nature=nature,
            version=version,
            term_importer=term_importer,
            annotator=annotator,
            processor=processor,
            formatter=formatter,
            converter=converter,
            segmenter=segmenter,
            language_guesser=language_guesser,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RoleDesc")


@attr.s(auto_attribs=True)
class RoleDesc:
    """
    Attributes:
        label (str):
        permissions (List[str]):
        rolename (str):
        type (str):
        created_at (Union[Unset, str]):
        created_by (Union[Unset, str]):
        group_name (Union[Unset, str]):
        modified_at (Union[Unset, str]):
        modified_by (Union[Unset, str]):
        predefined (Union[Unset, bool]):
    """

    label: str
    permissions: List[str]
    rolename: str
    type: str
    created_at: Union[Unset, str] = UNSET
    created_by: Union[Unset, str] = UNSET
    group_name: Union[Unset, str] = UNSET
    modified_at: Union[Unset, str] = UNSET
    modified_by: Union[Unset, str] = UNSET
    predefined: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        permissions = self.permissions

        rolename = self.rolename
        type = self.type
        created_at = self.created_at
        created_by = self.created_by
        group_name = self.group_name
        modified_at = self.modified_at
        modified_by = self.modified_by
        predefined = self.predefined

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "label": label,
                "permissions": permissions,
                "rolename": rolename,
                "type": type,
            }
        )
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if group_name is not UNSET:
            field_dict["groupName"] = group_name
        if modified_at is not UNSET:
            field_dict["modifiedAt"] = modified_at
        if modified_by is not UNSET:
            field_dict["modifiedBy"] = modified_by
        if predefined is not UNSET:
            field_dict["predefined"] = predefined

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        label = d.pop("label")

        permissions = cast(List[str], d.pop("permissions"))

        rolename = d.pop("rolename")

        type = d.pop("type")

        created_at = d.pop("createdAt", UNSET)

        created_by = d.pop("createdBy", UNSET)

        group_name = d.pop("groupName", UNSET)

        modified_at = d.pop("modifiedAt", UNSET)

        modified_by = d.pop("modifiedBy", UNSET)

        predefined = d.pop("predefined", UNSET)

        role_desc = cls(
            label=label,
            permissions=permissions,
            rolename=rolename,
            type=type,
            created_at=created_at,
            created_by=created_by,
            group_name=group_name,
            modified_at=modified_at,
            modified_by=modified_by,
            predefined=predefined,
        )

        return role_desc



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.doc_alt_text import DocAltText
    from ..models.doc_annotation import DocAnnotation
    from ..models.doc_category import DocCategory
    from ..models.doc_sentence import DocSentence
    from ..models.input_document_metadata import InputDocumentMetadata


T = TypeVar("T", bound="InputDocument")


@attr.s(auto_attribs=True)
class InputDocument:
    """
    Attributes:
        text (str): text of the document
        alt_texts (Union[Unset, List['DocAltText']]):
        annotations (Union[Unset, List['DocAnnotation']]):
        categories (Union[Unset, List['DocCategory']]):
        identifier (Union[Unset, str]): document identifier
        metadata (Union[Unset, InputDocumentMetadata]): document metadata
        sentences (Union[Unset, List['DocSentence']]):
        title (Union[Unset, str]): title of the document
    """

    text: str
    alt_texts: Union[Unset, List["DocAltText"]] = UNSET
    annotations: Union[Unset, List["DocAnnotation"]] = UNSET
    categories: Union[Unset, List["DocCategory"]] = UNSET
    identifier: Union[Unset, str] = UNSET
    metadata: Union[Unset, "InputDocumentMetadata"] = UNSET
    sentences: Union[Unset, List["DocSentence"]] = UNSET
    title: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        text = self.text
        alt_texts: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.alt_texts, Unset):
            alt_texts = []
            for alt_texts_item_data in self.alt_texts:
                alt_texts_item = alt_texts_item_data.to_dict()

                alt_texts.append(alt_texts_item)

        annotations: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.annotations, Unset):
            annotations = []
            for annotations_item_data in self.annotations:
                annotations_item = annotations_item_data.to_dict()

                annotations.append(annotations_item)

        categories: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.categories, Unset):
            categories = []
            for categories_item_data in self.categories:
                categories_item = categories_item_data.to_dict()

                categories.append(categories_item)

        identifier = self.identifier
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        sentences: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sentences, Unset):
            sentences = []
            for sentences_item_data in self.sentences:
                sentences_item = sentences_item_data.to_dict()

                sentences.append(sentences_item)

        title = self.title

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "text": text,
            }
        )
        if alt_texts is not UNSET:
            field_dict["altTexts"] = alt_texts
        if annotations is not UNSET:
            field_dict["annotations"] = annotations
        if categories is not UNSET:
            field_dict["categories"] = categories
        if identifier is not UNSET:
            field_dict["identifier"] = identifier
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if sentences is not UNSET:
            field_dict["sentences"] = sentences
        if title is not UNSET:
            field_dict["title"] = title

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.doc_alt_text import DocAltText
        from ..models.doc_annotation import DocAnnotation
        from ..models.doc_category import DocCategory
        from ..models.doc_sentence import DocSentence
        from ..models.input_document_metadata import InputDocumentMetadata

        d = src_dict.copy()
        text = d.pop("text")

        alt_texts = []
        _alt_texts = d.pop("altTexts", UNSET)
        for alt_texts_item_data in _alt_texts or []:
            alt_texts_item = DocAltText.from_dict(alt_texts_item_data)

            alt_texts.append(alt_texts_item)

        annotations = []
        _annotations = d.pop("annotations", UNSET)
        for annotations_item_data in _annotations or []:
            annotations_item = DocAnnotation.from_dict(annotations_item_data)

            annotations.append(annotations_item)

        categories = []
        _categories = d.pop("categories", UNSET)
        for categories_item_data in _categories or []:
            categories_item = DocCategory.from_dict(categories_item_data)

            categories.append(categories_item)

        identifier = d.pop("identifier", UNSET)

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, InputDocumentMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = InputDocumentMetadata.from_dict(_metadata)

        sentences = []
        _sentences = d.pop("sentences", UNSET)
        for sentences_item_data in _sentences or []:
            sentences_item = DocSentence.from_dict(sentences_item_data)

            sentences.append(sentences_item)

        title = d.pop("title", UNSET)

        input_document = cls(
            text=text,
            alt_texts=alt_texts,
            annotations=annotations,
            categories=categories,
            identifier=identifier,
            metadata=metadata,
            sentences=sentences,
            title=title,
        )

        return input_document



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.sherpa_job_bean import SherpaJobBean


T = TypeVar("T", bound="DeleteResponse")


@attr.s(auto_attribs=True)
class DeleteResponse:
    """
    Attributes:
        removed_count (int):
        remove_job (Union[Unset, SherpaJobBean]):
    """

    removed_count: int
    remove_job: Union[Unset, "SherpaJobBean"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        removed_count = self.removed_count
        remove_job: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.remove_job, Unset):
            remove_job = self.remove_job.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "removedCount": removed_count,
            }
        )
        if remove_job is not UNSET:
            field_dict["removeJob"] = remove_job

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sherpa_job_bean import SherpaJobBean

        d = src_dict.copy()
        removed_count = d.pop("removedCount")

        _remove_job = d.pop("removeJob", UNSET)
        remove_job: Union[Unset, SherpaJobBean]
        if isinstance(_remove_job, Unset):
            remove_job = UNSET
        else:
            remove_job = SherpaJobBean.from_dict(_remove_job)

        delete_response = cls(
            removed_count=removed_count,
            remove_job=remove_job,
        )

        return delete_response



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.segment_hits import SegmentHits
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    client: Client,
    segid: Union[Unset, None, str] = "",
    text: Union[Unset, None, str] = "",
    fields: Union[Unset, None, str] = "",
    from_: Union[Unset, None, int] = 0,
    size: Union[Unset, None, int] = 10,
    highlight: Union[Unset, None, bool] = False,
    facet: Union[Unset, None, bool] = False,
    query_filter: Union[Unset, None, str] = "",
    output_fields: Union[Unset, None, str] = "",
    simple_query: Union[Unset, None, bool] = False,
    selected_facets: Union[Unset, None, List[str]] = UNSET,
    html_version: Union[Unset, None, bool] = False,
) -> Dict[str, Any]:
    url = "{}/projects/{projectName}/segments/_similar".format(client.base_url, projectName=project_name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["segid"] = segid

    params["text"] = text

    params["fields"] = fields

    params["from"] = from_

    params["size"] = size

    params["highlight"] = highlight

    params["facet"] = facet

    params["queryFilter"] = query_filter

    params["outputFields"] = output_fields

    params["simpleQuery"] = simple_query

    json_selected_facets: Union[Unset, None, List[str]] = UNSET
    if not isinstance(selected_facets, Unset):
        if selected_facets is None:
            json_selected_facets = None
        else:
            json_selected_facets = selected_facets

    params["selectedFacets"] = json_selected_facets

    params["htmlVersion"] = html_version

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[SegmentHits]:
    if response.status_code == HTTPStatus.OK:
        response_200 = SegmentHits.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[SegmentHits]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Client,
    segid: Union[Unset, None, str] = "",
    text: Union[Unset, None, str] = "",
    fields: Union[Unset, None, str] = "",
    from_: Union[Unset, None, int] = 0,
    size: Union[Unset, None, int] = 10,
    highlight: Union[Unset, None, bool] = False,
    facet: Union[Unset, None, bool] = False,
    query_filter: Union[Unset, None, str] = "",
    output_fields: Union[Unset, None, str] = "",
    simple_query: Union[Unset, None, bool] = False,
    selected_facets: Union[Unset, None, List[str]] = UNSET,
    html_version: Union[Unset, None, bool] = False,
) -> Response[SegmentHits]:
    """Search for similar segments

    Args:
        project_name (str):
        segid (Union[Unset, None, str]):  Default: ''.
        text (Union[Unset, None, str]):  Default: ''.
        fields (Union[Unset, None, str]):  Default: ''.
        from_ (Union[Unset, None, int]):
        size (Union[Unset, None, int]):  Default: 10.
        highlight (Union[Unset, None, bool]):
        facet (Union[Unset, None, bool]):
        query_filter (Union[Unset, None, str]):  Default: ''.
        output_fields (Union[Unset, None, str]):  Default: ''.
        simple_query (Union[Unset, None, bool]):
        selected_facets (Union[Unset, None, List[str]]):
        html_version (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SegmentHits]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        segid=segid,
        text=text,
        fields=fields,
        from_=from_,
        size=size,
        highlight=highlight,
        facet=facet,
        query_filter=query_filter,
        output_fields=output_fields,
        simple_query=simple_query,
        selected_facets=selected_facets,
        html_version=html_version,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Client,
    segid: Union[Unset, None, str] = "",
    text: Union[Unset, None, str] = "",
    fields: Union[Unset, None, str] = "",
    from_: Union[Unset, None, int] = 0,
    size: Union[Unset, None, int] = 10,
    highlight: Union[Unset, None, bool] = False,
    facet: Union[Unset, None, bool] = False,
    query_filter: Union[Unset, None, str] = "",
    output_fields: Union[Unset, None, str] = "",
    simple_query: Union[Unset, None, bool] = False,
    selected_facets: Union[Unset, None, List[str]] = UNSET,
    html_version: Union[Unset, None, bool] = False,
) -> Optional[SegmentHits]:
    """Search for similar segments

    Args:
        project_name (str):
        segid (Union[Unset, None, str]):  Default: ''.
        text (Union[Unset, None, str]):  Default: ''.
        fields (Union[Unset, None, str]):  Default: ''.
        from_ (Union[Unset, None, int]):
        size (Union[Unset, None, int]):  Default: 10.
        highlight (Union[Unset, None, bool]):
        facet (Union[Unset, None, bool]):
        query_filter (Union[Unset, None, str]):  Default: ''.
        output_fields (Union[Unset, None, str]):  Default: ''.
        simple_query (Union[Unset, None, bool]):
        selected_facets (Union[Unset, None, List[str]]):
        html_version (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SegmentHits]
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        segid=segid,
        text=text,
        fields=fields,
        from_=from_,
        size=size,
        highlight=highlight,
        facet=facet,
        query_filter=query_filter,
        output_fields=output_fields,
        simple_query=simple_query,
        selected_facets=selected_facets,
        html_version=html_version,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Client,
    segid: Union[Unset, None, str] = "",
    text: Union[Unset, None, str] = "",
    fields: Union[Unset, None, str] = "",
    from_: Union[Unset, None, int] = 0,
    size: Union[Unset, None, int] = 10,
    highlight: Union[Unset, None, bool] = False,
    facet: Union[Unset, None, bool] = False,
    query_filter: Union[Unset, None, str] = "",
    output_fields: Union[Unset, None, str] = "",
    simple_query: Union[Unset, None, bool] = False,
    selected_facets: Union[Unset, None, List[str]] = UNSET,
    html_version: Union[Unset, None, bool] = False,
) -> Response[SegmentHits]:
    """Search for similar segments

    Args:
        project_name (str):
        segid (Union[Unset, None, str]):  Default: ''.
        text (Union[Unset, None, str]):  Default: ''.
        fields (Union[Unset, None, str]):  Default: ''.
        from_ (Union[Unset, None, int]):
        size (Union[Unset, None, int]):  Default: 10.
        highlight (Union[Unset, None, bool]):
        facet (Union[Unset, None, bool]):
        query_filter (Union[Unset, None, str]):  Default: ''.
        output_fields (Union[Unset, None, str]):  Default: ''.
        simple_query (Union[Unset, None, bool]):
        selected_facets (Union[Unset, None, List[str]]):
        html_version (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SegmentHits]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        segid=segid,
        text=text,
        fields=fields,
        from_=from_,
        size=size,
        highlight=highlight,
        facet=facet,
        query_filter=query_filter,
        output_fields=output_fields,
        simple_query=simple_query,
        selected_facets=selected_facets,
        html_version=html_version,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Client,
    segid: Union[Unset, None, str] = "",
    text: Union[Unset, None, str] = "",
    fields: Union[Unset, None, str] = "",
    from_: Union[Unset, None, int] = 0,
    size: Union[Unset, None, int] = 10,
    highlight: Union[Unset, None, bool] = False,
    facet: Union[Unset, None, bool] = False,
    query_filter: Union[Unset, None, str] = "",
    output_fields: Union[Unset, None, str] = "",
    simple_query: Union[Unset, None, bool] = False,
    selected_facets: Union[Unset, None, List[str]] = UNSET,
    html_version: Union[Unset, None, bool] = False,
) -> Optional[SegmentHits]:
    """Search for similar segments

    Args:
        project_name (str):
        segid (Union[Unset, None, str]):  Default: ''.
        text (Union[Unset, None, str]):  Default: ''.
        fields (Union[Unset, None, str]):  Default: ''.
        from_ (Union[Unset, None, int]):
        size (Union[Unset, None, int]):  Default: 10.
        highlight (Union[Unset, None, bool]):
        facet (Union[Unset, None, bool]):
        query_filter (Union[Unset, None, str]):  Default: ''.
        output_fields (Union[Unset, None, str]):  Default: ''.
        simple_query (Union[Unset, None, bool]):
        selected_facets (Union[Unset, None, List[str]]):
        html_version (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SegmentHits]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            segid=segid,
            text=text,
            fields=fields,
            from_=from_,
            size=size,
            highlight=highlight,
            facet=facet,
            query_filter=query_filter,
            output_fields=output_fields,
            simple_query=simple_query,
            selected_facets=selected_facets,
            html_version=html_version,
        )
    ).parsed



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Label")


@attr.s(auto_attribs=True)
class Label:
    """
    Attributes:
        color (str):
        label (str):
        name (str):
        count (Union[Unset, int]):
        guideline (Union[Unset, str]):
        identifier (Union[Unset, str]):
        label_set_name (Union[Unset, str]):
    """

    color: str
    label: str
    name: str
    count: Union[Unset, int] = UNSET
    guideline: Union[Unset, str] = UNSET
    identifier: Union[Unset, str] = UNSET
    label_set_name: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        color = self.color
        label = self.label
        name = self.name
        count = self.count
        guideline = self.guideline
        identifier = self.identifier
        label_set_name = self.label_set_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "color": color,
                "label": label,
                "name": name,
            }
        )
        if count is not UNSET:
            field_dict["count"] = count
        if guideline is not UNSET:
            field_dict["guideline"] = guideline
        if identifier is not UNSET:
            field_dict["identifier"] = identifier
        if label_set_name is not UNSET:
            field_dict["labelSetName"] = label_set_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        color = d.pop("color")

        label = d.pop("label")

        name = d.pop("name")

        count = d.pop("count", UNSET)

        guideline = d.pop("guideline", UNSET)

        identifier = d.pop("identifier", UNSET)

        label_set_name = d.pop("labelSetName", UNSET)

        label = cls(
            color=color,
            label=label,
            name=name,
            count=count,
            guideline=guideline,
            identifier=identifier,
            label_set_name=label_set_name,
        )

        return label



from typing import Any, Dict, Type, TypeVar

import attr

T = TypeVar("T", bound="Credentials")


@attr.s(auto_attribs=True)
class Credentials:
    """
    Attributes:
        email (str):
        password (str):
    """

    email: str
    password: str

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        password = self.password

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "email": email,
                "password": password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        password = d.pop("password")

        credentials = cls(
            email=email,
            password=password,
        )

        return credentials



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LabelNames")


@attr.s(auto_attribs=True)
class LabelNames:
    """
    Attributes:
        names (Union[Unset, List[str]]):
    """

    names: Union[Unset, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.names, Unset):
            names = self.names

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if names is not UNSET:
            field_dict["names"] = names

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        names = cast(List[str], d.pop("names", UNSET))

        label_names = cls(
            names=names,
        )

        return label_names



import ssl
from typing import Dict, Union

import attr


@attr.s(auto_attribs=True)
class Client:
    """A class for keeping track of data related to the API

    Attributes:
        base_url: The base URL for the API, all requests are made to a relative path to this URL
        cookies: A dictionary of cookies to be sent with every request
        headers: A dictionary of headers to be sent with every request
        timeout: The maximum amount of a time in seconds a request can take. API functions will raise
            httpx.TimeoutException if this is exceeded.
        verify_ssl: Whether or not to verify the SSL certificate of the API server. This should be True in production,
            but can be set to False for testing purposes.
        raise_on_unexpected_status: Whether or not to raise an errors.UnexpectedStatus if the API returns a
            status code that was not documented in the source OpenAPI document.
    """

    base_url: str
    cookies: Dict[str, str] = attr.ib(factory=dict, kw_only=True)
    headers: Dict[str, str] = attr.ib(factory=dict, kw_only=True)
    timeout: float = attr.ib(5.0, kw_only=True)
    verify_ssl: Union[str, bool, ssl.SSLContext] = attr.ib(True, kw_only=True)
    raise_on_unexpected_status: bool = attr.ib(False, kw_only=True)

    def get_headers(self) -> Dict[str, str]:
        """Get headers to be used in all endpoints"""
        return {**self.headers}

    def with_headers(self, headers: Dict[str, str]) -> "Client":
        """Get a new client matching this one with additional headers"""
        return attr.evolve(self, headers={**self.headers, **headers})

    def get_cookies(self) -> Dict[str, str]:
        return {**self.cookies}

    def with_cookies(self, cookies: Dict[str, str]) -> "Client":
        """Get a new client matching this one with additional cookies"""
        return attr.evolve(self, cookies={**self.cookies, **cookies})

    def get_timeout(self) -> float:
        return self.timeout

    def with_timeout(self, timeout: float) -> "Client":
        """Get a new client matching this one with a new timeout (in seconds)"""
        return attr.evolve(self, timeout=timeout)


@attr.s(auto_attribs=True)
class AuthenticatedClient(Client):
    """A Client which has been authenticated for use on secured endpoints"""

    token: str
    prefix: str = "Bearer"
    auth_header_name: str = "Authorization"

    def get_headers(self) -> Dict[str, str]:
        auth_header_value = f"{self.prefix} {self.token}" if self.prefix else self.token
        """Get headers to be used in authenticated endpoints"""
        if self.token is not None:
            return {self.auth_header_name: auth_header_value, **self.headers}
        else:
            return {**self.headers}


import pkg_resources
from httpx import BasicAuth
from httpx import Client as HttpxClient
from httpx import Response as HttpxResponse

from .models import BearerToken, Credentials, RequestJwtTokenProjectAccessMode
from .types import UNSET, Response, Unset


@attr.s(auto_attribs=True)
class SherpaClient(Client):
    """A Client logged"""

    token: str = attr.ib(init=True, default=None)
    prefix: str = "Bearer"
    auth_header_name: str = "Authorization"
    session_cookies: Dict[str, str] = attr.ib(factory=dict, kw_only=True, init=True)

    def get_headers(self) -> Dict[str, str]:
        auth_header_value = f"{self.prefix} {self.token}" if self.prefix else self.token
        """Get headers to be used in authenticated endpoints"""
        if self.token is not None:
            return {self.auth_header_name: auth_header_value, **self.headers}
        else:
            return {**self.headers}

    def get_cookies(self) -> Dict[str, str]:
        """Get cookies to be used in authenticated endpoints"""
        if self.session_cookies:
            return {**self.session_cookies, **self.cookies}
        else:
            return {**self.cookies}

    def login_with_cookie(self, credentials: Credentials):
        """ """
        my_version = pkg_resources.get_distribution("sherpa-client")
        httpx_client = HttpxClient(
            base_url=self.base_url,
            auth=BasicAuth(username=credentials.email, password=credentials.password),
            headers={"User-Agent": f"{my_version.key}/{my_version.parsed_version}"},
        )
        res: HttpxResponse = httpx_client.get("/users", params={"username": credentials.email})
        if res.is_success and res.cookies:
            self.session_cookies = {k: res.cookies[k] for k in res.cookies}
        else:
            res.raise_for_status()

    def login_with_token(
        self,
        credentials: Credentials,
        project_filter: Union[Unset, None, str] = UNSET,
        project_access_mode: Union[Unset, None, RequestJwtTokenProjectAccessMode] = UNSET,
        annotate_only: Union[Unset, None, bool] = False,
        login_only: Union[Unset, None, bool] = False,
    ):
        """ """
        from .api.authentication import request_jwt_token

        r: Response[BearerToken] = request_jwt_token.sync_detailed(
            client=self,
            json_body=credentials,
            project_filter=project_filter,
            project_access_mode=project_access_mode,
            annotate_only=annotate_only,
            login_only=login_only,
        )
        if r.is_success:
            self.token = r.parsed.access_token
        else:
            r.raise_for_status()



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.apply_to import ApplyTo
    from ..models.depends_on import DependsOn
    from ..models.next_step import NextStep
    from ..models.with_segmenter_condition import WithSegmenterCondition
    from ..models.with_segmenter_parameters import WithSegmenterParameters


T = TypeVar("T", bound="WithSegmenter")


@attr.s(auto_attribs=True)
class WithSegmenter:
    """
    Attributes:
        segmenter (str):
        apply_to (Union[Unset, ApplyTo]):
        condition (Union[Unset, WithSegmenterCondition]):
        depends_on (Union[Unset, DependsOn]):
        disabled (Union[Unset, bool]):
        group (Union[Unset, str]):
        id (Union[Unset, str]):
        next_steps (Union[Unset, List['NextStep']]):
        parameters (Union[Unset, WithSegmenterParameters]):
        project_name (Union[Unset, str]):
    """

    segmenter: str
    apply_to: Union[Unset, "ApplyTo"] = UNSET
    condition: Union[Unset, "WithSegmenterCondition"] = UNSET
    depends_on: Union[Unset, "DependsOn"] = UNSET
    disabled: Union[Unset, bool] = UNSET
    group: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    next_steps: Union[Unset, List["NextStep"]] = UNSET
    parameters: Union[Unset, "WithSegmenterParameters"] = UNSET
    project_name: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        segmenter = self.segmenter
        apply_to: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.apply_to, Unset):
            apply_to = self.apply_to.to_dict()

        condition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.condition, Unset):
            condition = self.condition.to_dict()

        depends_on: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.depends_on, Unset):
            depends_on = self.depends_on.to_dict()

        disabled = self.disabled
        group = self.group
        id = self.id
        next_steps: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.next_steps, Unset):
            next_steps = []
            for next_steps_item_data in self.next_steps:
                next_steps_item = next_steps_item_data.to_dict()

                next_steps.append(next_steps_item)

        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        project_name = self.project_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "segmenter": segmenter,
            }
        )
        if apply_to is not UNSET:
            field_dict["applyTo"] = apply_to
        if condition is not UNSET:
            field_dict["condition"] = condition
        if depends_on is not UNSET:
            field_dict["dependsOn"] = depends_on
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if group is not UNSET:
            field_dict["group"] = group
        if id is not UNSET:
            field_dict["id"] = id
        if next_steps is not UNSET:
            field_dict["nextSteps"] = next_steps
        if parameters is not UNSET:
            field_dict["parameters"] = parameters
        if project_name is not UNSET:
            field_dict["projectName"] = project_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.apply_to import ApplyTo
        from ..models.depends_on import DependsOn
        from ..models.next_step import NextStep
        from ..models.with_segmenter_condition import WithSegmenterCondition
        from ..models.with_segmenter_parameters import WithSegmenterParameters

        d = src_dict.copy()
        segmenter = d.pop("segmenter")

        _apply_to = d.pop("applyTo", UNSET)
        apply_to: Union[Unset, ApplyTo]
        if isinstance(_apply_to, Unset):
            apply_to = UNSET
        else:
            apply_to = ApplyTo.from_dict(_apply_to)

        _condition = d.pop("condition", UNSET)
        condition: Union[Unset, WithSegmenterCondition]
        if isinstance(_condition, Unset):
            condition = UNSET
        else:
            condition = WithSegmenterCondition.from_dict(_condition)

        _depends_on = d.pop("dependsOn", UNSET)
        depends_on: Union[Unset, DependsOn]
        if isinstance(_depends_on, Unset):
            depends_on = UNSET
        else:
            depends_on = DependsOn.from_dict(_depends_on)

        disabled = d.pop("disabled", UNSET)

        group = d.pop("group", UNSET)

        id = d.pop("id", UNSET)

        next_steps = []
        _next_steps = d.pop("nextSteps", UNSET)
        for next_steps_item_data in _next_steps or []:
            next_steps_item = NextStep.from_dict(next_steps_item_data)

            next_steps.append(next_steps_item)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, WithSegmenterParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = WithSegmenterParameters.from_dict(_parameters)

        project_name = d.pop("projectName", UNSET)

        with_segmenter = cls(
            segmenter=segmenter,
            apply_to=apply_to,
            condition=condition,
            depends_on=depends_on,
            disabled=disabled,
            group=group,
            id=id,
            next_steps=next_steps,
            parameters=parameters,
            project_name=project_name,
        )

        return with_segmenter



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.sherpa_job_bean import SherpaJobBean


T = TypeVar("T", bound="EngineConfigImportSummary")


@attr.s(auto_attribs=True)
class EngineConfigImportSummary:
    """
    Attributes:
        configs (Union[Unset, List[str]]):
        ignored (Union[Unset, List[str]]):
        models (Union[Unset, int]): number of models that will be imported
        pending_job (Union[Unset, SherpaJobBean]):
    """

    configs: Union[Unset, List[str]] = UNSET
    ignored: Union[Unset, List[str]] = UNSET
    models: Union[Unset, int] = 0
    pending_job: Union[Unset, "SherpaJobBean"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        configs: Union[Unset, List[str]] = UNSET
        if not isinstance(self.configs, Unset):
            configs = self.configs

        ignored: Union[Unset, List[str]] = UNSET
        if not isinstance(self.ignored, Unset):
            ignored = self.ignored

        models = self.models
        pending_job: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pending_job, Unset):
            pending_job = self.pending_job.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if configs is not UNSET:
            field_dict["configs"] = configs
        if ignored is not UNSET:
            field_dict["ignored"] = ignored
        if models is not UNSET:
            field_dict["models"] = models
        if pending_job is not UNSET:
            field_dict["pendingJob"] = pending_job

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sherpa_job_bean import SherpaJobBean

        d = src_dict.copy()
        configs = cast(List[str], d.pop("configs", UNSET))

        ignored = cast(List[str], d.pop("ignored", UNSET))

        models = d.pop("models", UNSET)

        _pending_job = d.pop("pendingJob", UNSET)
        pending_job: Union[Unset, SherpaJobBean]
        if isinstance(_pending_job, Unset):
            pending_job = UNSET
        else:
            pending_job = SherpaJobBean.from_dict(_pending_job)

        engine_config_import_summary = cls(
            configs=configs,
            ignored=ignored,
            models=models,
            pending_job=pending_job,
        )

        return engine_config_import_summary



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.engine_config import EngineConfig
    from ..models.quality_figures import QualityFigures
    from ..models.report_classes import ReportClasses


T = TypeVar("T", bound="Report")


@attr.s(auto_attribs=True)
class Report:
    """
    Attributes:
        classes (ReportClasses):
        micro_avg (QualityFigures):
        config (Union[Unset, EngineConfig]):
        macro_avg (Union[Unset, QualityFigures]):
        samples_avg (Union[Unset, QualityFigures]):
        weighted_avg (Union[Unset, QualityFigures]):
    """

    classes: "ReportClasses"
    micro_avg: "QualityFigures"
    config: Union[Unset, "EngineConfig"] = UNSET
    macro_avg: Union[Unset, "QualityFigures"] = UNSET
    samples_avg: Union[Unset, "QualityFigures"] = UNSET
    weighted_avg: Union[Unset, "QualityFigures"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        classes = self.classes.to_dict()

        micro_avg = self.micro_avg.to_dict()

        config: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.config, Unset):
            config = self.config.to_dict()

        macro_avg: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.macro_avg, Unset):
            macro_avg = self.macro_avg.to_dict()

        samples_avg: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.samples_avg, Unset):
            samples_avg = self.samples_avg.to_dict()

        weighted_avg: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.weighted_avg, Unset):
            weighted_avg = self.weighted_avg.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "classes": classes,
                "microAvg": micro_avg,
            }
        )
        if config is not UNSET:
            field_dict["config"] = config
        if macro_avg is not UNSET:
            field_dict["macroAvg"] = macro_avg
        if samples_avg is not UNSET:
            field_dict["samplesAvg"] = samples_avg
        if weighted_avg is not UNSET:
            field_dict["weightedAvg"] = weighted_avg

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.engine_config import EngineConfig
        from ..models.quality_figures import QualityFigures
        from ..models.report_classes import ReportClasses

        d = src_dict.copy()
        classes = ReportClasses.from_dict(d.pop("classes"))

        micro_avg = QualityFigures.from_dict(d.pop("microAvg"))

        _config = d.pop("config", UNSET)
        config: Union[Unset, EngineConfig]
        if isinstance(_config, Unset):
            config = UNSET
        else:
            config = EngineConfig.from_dict(_config)

        _macro_avg = d.pop("macroAvg", UNSET)
        macro_avg: Union[Unset, QualityFigures]
        if isinstance(_macro_avg, Unset):
            macro_avg = UNSET
        else:
            macro_avg = QualityFigures.from_dict(_macro_avg)

        _samples_avg = d.pop("samplesAvg", UNSET)
        samples_avg: Union[Unset, QualityFigures]
        if isinstance(_samples_avg, Unset):
            samples_avg = UNSET
        else:
            samples_avg = QualityFigures.from_dict(_samples_avg)

        _weighted_avg = d.pop("weightedAvg", UNSET)
        weighted_avg: Union[Unset, QualityFigures]
        if isinstance(_weighted_avg, Unset):
            weighted_avg = UNSET
        else:
            weighted_avg = QualityFigures.from_dict(_weighted_avg)

        report = cls(
            classes=classes,
            micro_avg=micro_avg,
            config=config,
            macro_avg=macro_avg,
            samples_avg=samples_avg,
            weighted_avg=weighted_avg,
        )

        return report



from typing import Any, Dict, Type, TypeVar

import attr

T = TypeVar("T", bound="CreatedByCount")


@attr.s(auto_attribs=True)
class CreatedByCount:
    """
    Attributes:
        count (int):
        created_by (str):
    """

    count: int
    created_by: str

    def to_dict(self) -> Dict[str, Any]:
        count = self.count
        created_by = self.created_by

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "count": count,
                "createdBy": created_by,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        count = d.pop("count")

        created_by = d.pop("createdBy")

        created_by_count = cls(
            count=count,
            created_by=created_by,
        )

        return created_by_count



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.suggester_patch_parameters import SuggesterPatchParameters


T = TypeVar("T", bound="SuggesterPatch")


@attr.s(auto_attribs=True)
class SuggesterPatch:
    """
    Attributes:
        label (Union[Unset, str]):
        parameters (Union[Unset, SuggesterPatchParameters]):
        tags (Union[Unset, List[str]]):
    """

    label: Union[Unset, str] = UNSET
    parameters: Union[Unset, "SuggesterPatchParameters"] = UNSET
    tags: Union[Unset, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if label is not UNSET:
            field_dict["label"] = label
        if parameters is not UNSET:
            field_dict["parameters"] = parameters
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.suggester_patch_parameters import SuggesterPatchParameters

        d = src_dict.copy()
        label = d.pop("label", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, SuggesterPatchParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = SuggesterPatchParameters.from_dict(_parameters)

        tags = cast(List[str], d.pop("tags", UNSET))

        suggester_patch = cls(
            label=label,
            parameters=parameters,
            tags=tags,
        )

        return suggester_patch



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.doc_category import DocCategory
    from ..models.doc_sentence_metadata import DocSentenceMetadata


T = TypeVar("T", bound="DocSentence")


@attr.s(auto_attribs=True)
class DocSentence:
    """
    Attributes:
        end (int):
        start (int):
        categories (Union[Unset, List['DocCategory']]):
        metadata (Union[Unset, DocSentenceMetadata]):
    """

    end: int
    start: int
    categories: Union[Unset, List["DocCategory"]] = UNSET
    metadata: Union[Unset, "DocSentenceMetadata"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        end = self.end
        start = self.start
        categories: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.categories, Unset):
            categories = []
            for categories_item_data in self.categories:
                categories_item = categories_item_data.to_dict()

                categories.append(categories_item)

        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "end": end,
                "start": start,
            }
        )
        if categories is not UNSET:
            field_dict["categories"] = categories
        if metadata is not UNSET:
            field_dict["metadata"] = metadata

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.doc_category import DocCategory
        from ..models.doc_sentence_metadata import DocSentenceMetadata

        d = src_dict.copy()
        end = d.pop("end")

        start = d.pop("start")

        categories = []
        _categories = d.pop("categories", UNSET)
        for categories_item_data in _categories or []:
            categories_item = DocCategory.from_dict(categories_item_data)

            categories.append(categories_item)

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, DocSentenceMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = DocSentenceMetadata.from_dict(_metadata)

        doc_sentence = cls(
            end=end,
            start=start,
            categories=categories,
            metadata=metadata,
        )

        return doc_sentence



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.project_open_session_state import ProjectOpenSessionState
from ..types import UNSET, Unset

T = TypeVar("T", bound="ProjectOpenSession")


@attr.s(auto_attribs=True)
class ProjectOpenSession:
    """
    Attributes:
        campaign_id (str):
        duration (int):
        label (str):
        remaining_duration (int):
        session_id (str):
        state (ProjectOpenSessionState):
        id (Union[Unset, str]):
    """

    campaign_id: str
    duration: int
    label: str
    remaining_duration: int
    session_id: str
    state: ProjectOpenSessionState
    id: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        campaign_id = self.campaign_id
        duration = self.duration
        label = self.label
        remaining_duration = self.remaining_duration
        session_id = self.session_id
        state = self.state.value

        id = self.id

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "campaignId": campaign_id,
                "duration": duration,
                "label": label,
                "remainingDuration": remaining_duration,
                "sessionId": session_id,
                "state": state,
            }
        )
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        campaign_id = d.pop("campaignId")

        duration = d.pop("duration")

        label = d.pop("label")

        remaining_duration = d.pop("remainingDuration")

        session_id = d.pop("sessionId")

        state = ProjectOpenSessionState(d.pop("state"))

        id = d.pop("id", UNSET)

        project_open_session = cls(
            campaign_id=campaign_id,
            duration=duration,
            label=label,
            remaining_duration=remaining_duration,
            session_id=session_id,
            state=state,
            id=id,
        )

        return project_open_session



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.http_service_metadata_operations import HttpServiceMetadataOperations


T = TypeVar("T", bound="HttpServiceMetadata")


@attr.s(auto_attribs=True)
class HttpServiceMetadata:
    """
    Attributes:
        api (str):
        compatibility (str):
        version (str):
        annotators (Union[Unset, str]):
        converters (Union[Unset, str]):
        engine (Union[Unset, str]):
        extensions (Union[Unset, str]):
        formatters (Union[Unset, str]):
        functions (Union[Unset, str]):
        language_guessers (Union[Unset, str]):
        languages (Union[Unset, str]):
        natures (Union[Unset, str]):
        operations (Union[Unset, HttpServiceMetadataOperations]):
        processors (Union[Unset, str]):
        segmenters (Union[Unset, str]):
        term_importers (Union[Unset, str]):
        trigger (Union[Unset, str]):
    """

    api: str
    compatibility: str
    version: str
    annotators: Union[Unset, str] = UNSET
    converters: Union[Unset, str] = UNSET
    engine: Union[Unset, str] = UNSET
    extensions: Union[Unset, str] = UNSET
    formatters: Union[Unset, str] = UNSET
    functions: Union[Unset, str] = UNSET
    language_guessers: Union[Unset, str] = UNSET
    languages: Union[Unset, str] = UNSET
    natures: Union[Unset, str] = UNSET
    operations: Union[Unset, "HttpServiceMetadataOperations"] = UNSET
    processors: Union[Unset, str] = UNSET
    segmenters: Union[Unset, str] = UNSET
    term_importers: Union[Unset, str] = UNSET
    trigger: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        api = self.api
        compatibility = self.compatibility
        version = self.version
        annotators = self.annotators
        converters = self.converters
        engine = self.engine
        extensions = self.extensions
        formatters = self.formatters
        functions = self.functions
        language_guessers = self.language_guessers
        languages = self.languages
        natures = self.natures
        operations: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.operations, Unset):
            operations = self.operations.to_dict()

        processors = self.processors
        segmenters = self.segmenters
        term_importers = self.term_importers
        trigger = self.trigger

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "api": api,
                "compatibility": compatibility,
                "version": version,
            }
        )
        if annotators is not UNSET:
            field_dict["annotators"] = annotators
        if converters is not UNSET:
            field_dict["converters"] = converters
        if engine is not UNSET:
            field_dict["engine"] = engine
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if formatters is not UNSET:
            field_dict["formatters"] = formatters
        if functions is not UNSET:
            field_dict["functions"] = functions
        if language_guessers is not UNSET:
            field_dict["languageGuessers"] = language_guessers
        if languages is not UNSET:
            field_dict["languages"] = languages
        if natures is not UNSET:
            field_dict["natures"] = natures
        if operations is not UNSET:
            field_dict["operations"] = operations
        if processors is not UNSET:
            field_dict["processors"] = processors
        if segmenters is not UNSET:
            field_dict["segmenters"] = segmenters
        if term_importers is not UNSET:
            field_dict["termImporters"] = term_importers
        if trigger is not UNSET:
            field_dict["trigger"] = trigger

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.http_service_metadata_operations import HttpServiceMetadataOperations

        d = src_dict.copy()
        api = d.pop("api")

        compatibility = d.pop("compatibility")

        version = d.pop("version")

        annotators = d.pop("annotators", UNSET)

        converters = d.pop("converters", UNSET)

        engine = d.pop("engine", UNSET)

        extensions = d.pop("extensions", UNSET)

        formatters = d.pop("formatters", UNSET)

        functions = d.pop("functions", UNSET)

        language_guessers = d.pop("languageGuessers", UNSET)

        languages = d.pop("languages", UNSET)

        natures = d.pop("natures", UNSET)

        _operations = d.pop("operations", UNSET)
        operations: Union[Unset, HttpServiceMetadataOperations]
        if isinstance(_operations, Unset):
            operations = UNSET
        else:
            operations = HttpServiceMetadataOperations.from_dict(_operations)

        processors = d.pop("processors", UNSET)

        segmenters = d.pop("segmenters", UNSET)

        term_importers = d.pop("termImporters", UNSET)

        trigger = d.pop("trigger", UNSET)

        http_service_metadata = cls(
            api=api,
            compatibility=compatibility,
            version=version,
            annotators=annotators,
            converters=converters,
            engine=engine,
            extensions=extensions,
            formatters=formatters,
            functions=functions,
            language_guessers=language_guessers,
            languages=languages,
            natures=natures,
            operations=operations,
            processors=processors,
            segmenters=segmenters,
            term_importers=term_importers,
            trigger=trigger,
        )

        return http_service_metadata



from enum import Enum


class DocAnnotationCreationMode(str, Enum):
    MANUAL = "manual"
    AUTOMATIC = "automatic"
    UNDEFINED = "undefined"

    def __str__(self) -> str:
        return str(self.value)



from io import BytesIO
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, File, FileJsonType, Unset

T = TypeVar("T", bound="DeprecatedAnnotateBinaryWithPlanRefMultipartData")


@attr.s(auto_attribs=True)
class DeprecatedAnnotateBinaryWithPlanRefMultipartData:
    """
    Attributes:
        file (Union[Unset, File]):
    """

    file: Union[Unset, File] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if file is not UNSET:
            field_dict["file"] = file

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {key: (None, str(value).encode(), "text/plain") for key, value in self.additional_properties.items()}
        )
        field_dict.update({})
        if file is not UNSET:
            field_dict["file"] = file

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _file = d.pop("file", UNSET)
        file: Union[Unset, File]
        if isinstance(_file, Unset):
            file = UNSET
        else:
            file = File(payload=BytesIO(_file))

        deprecated_annotate_binary_with_plan_ref_multipart_data = cls(
            file=file,
        )

        deprecated_annotate_binary_with_plan_ref_multipart_data.additional_properties = d
        return deprecated_annotate_binary_with_plan_ref_multipart_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.converter import Converter
    from ..models.formatter import Formatter
    from ..models.segmenter import Segmenter
    from ..models.with_annotator import WithAnnotator
    from ..models.with_language_guesser import WithLanguageGuesser
    from ..models.with_processor import WithProcessor
    from ..models.with_segmenter import WithSegmenter


T = TypeVar("T", bound="ConvertFormatAnnotationPlan")


@attr.s(auto_attribs=True)
class ConvertFormatAnnotationPlan:
    """
    Attributes:
        formatter (Formatter):
        pipeline (List[Union['WithAnnotator', 'WithLanguageGuesser', 'WithProcessor', 'WithSegmenter']]):
        converter (Union[Unset, Converter]):
        segmenter (Union[Unset, Segmenter]):
    """

    formatter: "Formatter"
    pipeline: List[Union["WithAnnotator", "WithLanguageGuesser", "WithProcessor", "WithSegmenter"]]
    converter: Union[Unset, "Converter"] = UNSET
    segmenter: Union[Unset, "Segmenter"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        from ..models.with_annotator import WithAnnotator
        from ..models.with_language_guesser import WithLanguageGuesser
        from ..models.with_processor import WithProcessor

        formatter = self.formatter.to_dict()

        pipeline = []
        for pipeline_item_data in self.pipeline:
            pipeline_item: Dict[str, Any]

            if isinstance(pipeline_item_data, WithAnnotator):
                pipeline_item = pipeline_item_data.to_dict()

            elif isinstance(pipeline_item_data, WithProcessor):
                pipeline_item = pipeline_item_data.to_dict()

            elif isinstance(pipeline_item_data, WithLanguageGuesser):
                pipeline_item = pipeline_item_data.to_dict()

            else:
                pipeline_item = pipeline_item_data.to_dict()

            pipeline.append(pipeline_item)

        converter: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.converter, Unset):
            converter = self.converter.to_dict()

        segmenter: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.segmenter, Unset):
            segmenter = self.segmenter.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "formatter": formatter,
                "pipeline": pipeline,
            }
        )
        if converter is not UNSET:
            field_dict["converter"] = converter
        if segmenter is not UNSET:
            field_dict["segmenter"] = segmenter

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.converter import Converter
        from ..models.formatter import Formatter
        from ..models.segmenter import Segmenter
        from ..models.with_annotator import WithAnnotator
        from ..models.with_language_guesser import WithLanguageGuesser
        from ..models.with_processor import WithProcessor
        from ..models.with_segmenter import WithSegmenter

        d = src_dict.copy()
        formatter = Formatter.from_dict(d.pop("formatter"))

        pipeline = []
        _pipeline = d.pop("pipeline")
        for pipeline_item_data in _pipeline:

            def _parse_pipeline_item(
                data: object,
            ) -> Union["WithAnnotator", "WithLanguageGuesser", "WithProcessor", "WithSegmenter"]:
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_0 = WithAnnotator.from_dict(data)

                    return pipeline_item_type_0
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_1 = WithProcessor.from_dict(data)

                    return pipeline_item_type_1
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_2 = WithLanguageGuesser.from_dict(data)

                    return pipeline_item_type_2
                except:  # noqa: E722
                    pass
                if not isinstance(data, dict):
                    raise TypeError()
                pipeline_item_type_3 = WithSegmenter.from_dict(data)

                return pipeline_item_type_3

            pipeline_item = _parse_pipeline_item(pipeline_item_data)

            pipeline.append(pipeline_item)

        _converter = d.pop("converter", UNSET)
        converter: Union[Unset, Converter]
        if isinstance(_converter, Unset):
            converter = UNSET
        else:
            converter = Converter.from_dict(_converter)

        _segmenter = d.pop("segmenter", UNSET)
        segmenter: Union[Unset, Segmenter]
        if isinstance(_segmenter, Unset):
            segmenter = UNSET
        else:
            segmenter = Segmenter.from_dict(_segmenter)

        convert_format_annotation_plan = cls(
            formatter=formatter,
            pipeline=pipeline,
            converter=converter,
            segmenter=segmenter,
        )

        return convert_format_annotation_plan



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.user_response import UserResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    group_name: Union[Unset, None, str] = UNSET,
    admin_data: Union[Unset, None, bool] = False,
) -> Dict[str, Any]:
    url = "{}/users".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["groupName"] = group_name

    params["adminData"] = admin_data

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["UserResponse"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_user_response_array_item_data in _response_200:
            componentsschemas_user_response_array_item = UserResponse.from_dict(
                componentsschemas_user_response_array_item_data
            )

            response_200.append(componentsschemas_user_response_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[List["UserResponse"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    group_name: Union[Unset, None, str] = UNSET,
    admin_data: Union[Unset, None, bool] = False,
) -> Response[List["UserResponse"]]:
    """Get users

    Args:
        group_name (Union[Unset, None, str]):
        admin_data (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['UserResponse']]
    """

    kwargs = _get_kwargs(
        client=client,
        group_name=group_name,
        admin_data=admin_data,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    group_name: Union[Unset, None, str] = UNSET,
    admin_data: Union[Unset, None, bool] = False,
) -> Optional[List["UserResponse"]]:
    """Get users

    Args:
        group_name (Union[Unset, None, str]):
        admin_data (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['UserResponse']]
    """

    return sync_detailed(
        client=client,
        group_name=group_name,
        admin_data=admin_data,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    group_name: Union[Unset, None, str] = UNSET,
    admin_data: Union[Unset, None, bool] = False,
) -> Response[List["UserResponse"]]:
    """Get users

    Args:
        group_name (Union[Unset, None, str]):
        admin_data (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['UserResponse']]
    """

    kwargs = _get_kwargs(
        client=client,
        group_name=group_name,
        admin_data=admin_data,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    group_name: Union[Unset, None, str] = UNSET,
    admin_data: Union[Unset, None, bool] = False,
) -> Optional[List["UserResponse"]]:
    """Get users

    Args:
        group_name (Union[Unset, None, str]):
        admin_data (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['UserResponse']]
    """

    return (
        await asyncio_detailed(
            client=client,
            group_name=group_name,
            admin_data=admin_data,
        )
    ).parsed



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.launch_uploaded_document_import_segmentation_policy import LaunchUploadedDocumentImportSegmentationPolicy
from ...models.sherpa_job_bean import SherpaJobBean
from ...models.uploaded_file import UploadedFile
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    client: Client,
    json_body: List["UploadedFile"],
    ignore_labelling: Union[Unset, None, bool] = False,
    segmentation_policy: Union[
        Unset, None, LaunchUploadedDocumentImportSegmentationPolicy
    ] = LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, None, bool] = False,
    clean_text: Union[Unset, None, bool] = True,
    generate_categories_from_source_folder: Union[Unset, None, bool] = False,
) -> Dict[str, Any]:
    url = "{}/projects/{projectName}/documents/_load".format(client.base_url, projectName=project_name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["ignoreLabelling"] = ignore_labelling

    json_segmentation_policy: Union[Unset, None, str] = UNSET
    if not isinstance(segmentation_policy, Unset):
        json_segmentation_policy = segmentation_policy.value if segmentation_policy else None

    params["segmentationPolicy"] = json_segmentation_policy

    params["splitCorpus"] = split_corpus

    params["cleanText"] = clean_text

    params["generateCategoriesFromSourceFolder"] = generate_categories_from_source_folder

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = []
    for componentsschemas_uploaded_file_array_item_data in json_body:
        componentsschemas_uploaded_file_array_item = componentsschemas_uploaded_file_array_item_data.to_dict()

        json_json_body.append(componentsschemas_uploaded_file_array_item)

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[SherpaJobBean]:
    if response.status_code == HTTPStatus.OK:
        response_200 = SherpaJobBean.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[SherpaJobBean]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Client,
    json_body: List["UploadedFile"],
    ignore_labelling: Union[Unset, None, bool] = False,
    segmentation_policy: Union[
        Unset, None, LaunchUploadedDocumentImportSegmentationPolicy
    ] = LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, None, bool] = False,
    clean_text: Union[Unset, None, bool] = True,
    generate_categories_from_source_folder: Union[Unset, None, bool] = False,
) -> Response[SherpaJobBean]:
    """import documents already uploaded on the server into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, None, bool]):
        segmentation_policy (Union[Unset, None, LaunchUploadedDocumentImportSegmentationPolicy]):
            Default: LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, None, bool]):
        clean_text (Union[Unset, None, bool]):  Default: True.
        generate_categories_from_source_folder (Union[Unset, None, bool]):
        json_body (List['UploadedFile']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        json_body=json_body,
        ignore_labelling=ignore_labelling,
        segmentation_policy=segmentation_policy,
        split_corpus=split_corpus,
        clean_text=clean_text,
        generate_categories_from_source_folder=generate_categories_from_source_folder,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Client,
    json_body: List["UploadedFile"],
    ignore_labelling: Union[Unset, None, bool] = False,
    segmentation_policy: Union[
        Unset, None, LaunchUploadedDocumentImportSegmentationPolicy
    ] = LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, None, bool] = False,
    clean_text: Union[Unset, None, bool] = True,
    generate_categories_from_source_folder: Union[Unset, None, bool] = False,
) -> Optional[SherpaJobBean]:
    """import documents already uploaded on the server into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, None, bool]):
        segmentation_policy (Union[Unset, None, LaunchUploadedDocumentImportSegmentationPolicy]):
            Default: LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, None, bool]):
        clean_text (Union[Unset, None, bool]):  Default: True.
        generate_categories_from_source_folder (Union[Unset, None, bool]):
        json_body (List['UploadedFile']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        json_body=json_body,
        ignore_labelling=ignore_labelling,
        segmentation_policy=segmentation_policy,
        split_corpus=split_corpus,
        clean_text=clean_text,
        generate_categories_from_source_folder=generate_categories_from_source_folder,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Client,
    json_body: List["UploadedFile"],
    ignore_labelling: Union[Unset, None, bool] = False,
    segmentation_policy: Union[
        Unset, None, LaunchUploadedDocumentImportSegmentationPolicy
    ] = LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, None, bool] = False,
    clean_text: Union[Unset, None, bool] = True,
    generate_categories_from_source_folder: Union[Unset, None, bool] = False,
) -> Response[SherpaJobBean]:
    """import documents already uploaded on the server into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, None, bool]):
        segmentation_policy (Union[Unset, None, LaunchUploadedDocumentImportSegmentationPolicy]):
            Default: LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, None, bool]):
        clean_text (Union[Unset, None, bool]):  Default: True.
        generate_categories_from_source_folder (Union[Unset, None, bool]):
        json_body (List['UploadedFile']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        json_body=json_body,
        ignore_labelling=ignore_labelling,
        segmentation_policy=segmentation_policy,
        split_corpus=split_corpus,
        clean_text=clean_text,
        generate_categories_from_source_folder=generate_categories_from_source_folder,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Client,
    json_body: List["UploadedFile"],
    ignore_labelling: Union[Unset, None, bool] = False,
    segmentation_policy: Union[
        Unset, None, LaunchUploadedDocumentImportSegmentationPolicy
    ] = LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, None, bool] = False,
    clean_text: Union[Unset, None, bool] = True,
    generate_categories_from_source_folder: Union[Unset, None, bool] = False,
) -> Optional[SherpaJobBean]:
    """import documents already uploaded on the server into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, None, bool]):
        segmentation_policy (Union[Unset, None, LaunchUploadedDocumentImportSegmentationPolicy]):
            Default: LaunchUploadedDocumentImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, None, bool]):
        clean_text (Union[Unset, None, bool]):  Default: True.
        generate_categories_from_source_folder (Union[Unset, None, bool]):
        json_body (List['UploadedFile']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            json_body=json_body,
            ignore_labelling=ignore_labelling,
            segmentation_policy=segmentation_policy,
            split_corpus=split_corpus,
            clean_text=clean_text,
            generate_categories_from_source_folder=generate_categories_from_source_folder,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.doc_annotation import DocAnnotation
    from ..models.doc_category import DocCategory
    from ..models.segment_metadata import SegmentMetadata


T = TypeVar("T", bound="Segment")


@attr.s(auto_attribs=True)
class Segment:
    """
    Attributes:
        document_identifier (str):
        document_title (str):
        end (int):
        identifier (str):
        start (int):
        text (str):
        annotations (Union[Unset, List['DocAnnotation']]):
        categories (Union[Unset, List['DocCategory']]):
        created_by (Union[Unset, str]): User having created the segment
        created_date (Union[Unset, str]): Creation date
        metadata (Union[Unset, SegmentMetadata]):
        modified_date (Union[Unset, str]): Last modification date
        shift (Union[Unset, int]):
    """

    document_identifier: str
    document_title: str
    end: int
    identifier: str
    start: int
    text: str
    annotations: Union[Unset, List["DocAnnotation"]] = UNSET
    categories: Union[Unset, List["DocCategory"]] = UNSET
    created_by: Union[Unset, str] = UNSET
    created_date: Union[Unset, str] = UNSET
    metadata: Union[Unset, "SegmentMetadata"] = UNSET
    modified_date: Union[Unset, str] = UNSET
    shift: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        document_identifier = self.document_identifier
        document_title = self.document_title
        end = self.end
        identifier = self.identifier
        start = self.start
        text = self.text
        annotations: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.annotations, Unset):
            annotations = []
            for annotations_item_data in self.annotations:
                annotations_item = annotations_item_data.to_dict()

                annotations.append(annotations_item)

        categories: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.categories, Unset):
            categories = []
            for categories_item_data in self.categories:
                categories_item = categories_item_data.to_dict()

                categories.append(categories_item)

        created_by = self.created_by
        created_date = self.created_date
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        modified_date = self.modified_date
        shift = self.shift

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "documentIdentifier": document_identifier,
                "documentTitle": document_title,
                "end": end,
                "identifier": identifier,
                "start": start,
                "text": text,
            }
        )
        if annotations is not UNSET:
            field_dict["annotations"] = annotations
        if categories is not UNSET:
            field_dict["categories"] = categories
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if created_date is not UNSET:
            field_dict["createdDate"] = created_date
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if modified_date is not UNSET:
            field_dict["modifiedDate"] = modified_date
        if shift is not UNSET:
            field_dict["shift"] = shift

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.doc_annotation import DocAnnotation
        from ..models.doc_category import DocCategory
        from ..models.segment_metadata import SegmentMetadata

        d = src_dict.copy()
        document_identifier = d.pop("documentIdentifier")

        document_title = d.pop("documentTitle")

        end = d.pop("end")

        identifier = d.pop("identifier")

        start = d.pop("start")

        text = d.pop("text")

        annotations = []
        _annotations = d.pop("annotations", UNSET)
        for annotations_item_data in _annotations or []:
            annotations_item = DocAnnotation.from_dict(annotations_item_data)

            annotations.append(annotations_item)

        categories = []
        _categories = d.pop("categories", UNSET)
        for categories_item_data in _categories or []:
            categories_item = DocCategory.from_dict(categories_item_data)

            categories.append(categories_item)

        created_by = d.pop("createdBy", UNSET)

        created_date = d.pop("createdDate", UNSET)

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, SegmentMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = SegmentMetadata.from_dict(_metadata)

        modified_date = d.pop("modifiedDate", UNSET)

        shift = d.pop("shift", UNSET)

        segment = cls(
            document_identifier=document_identifier,
            document_title=document_title,
            end=end,
            identifier=identifier,
            start=start,
            text=text,
            annotations=annotations,
            categories=categories,
            created_by=created_by,
            created_date=created_date,
            metadata=metadata,
            modified_date=modified_date,
            shift=shift,
        )

        return segment



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="DocAltText")


@attr.s(auto_attribs=True)
class DocAltText:
    """A document alternative text

    Attributes:
        name (str): The alternative text name
        text (str): The alternative text
        created_by (Union[Unset, str]): User having created the category
        created_date (Union[Unset, str]): Creation date
        modified_date (Union[Unset, str]): Last modification date
    """

    name: str
    text: str
    created_by: Union[Unset, str] = UNSET
    created_date: Union[Unset, str] = UNSET
    modified_date: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        text = self.text
        created_by = self.created_by
        created_date = self.created_date
        modified_date = self.modified_date

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
                "text": text,
            }
        )
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if created_date is not UNSET:
            field_dict["createdDate"] = created_date
        if modified_date is not UNSET:
            field_dict["modifiedDate"] = modified_date

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        text = d.pop("text")

        created_by = d.pop("createdBy", UNSET)

        created_date = d.pop("createdDate", UNSET)

        modified_date = d.pop("modifiedDate", UNSET)

        doc_alt_text = cls(
            name=name,
            text=text,
            created_by=created_by,
            created_date=created_date,
            modified_date=modified_date,
        )

        return doc_alt_text



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="PartialLabel")


@attr.s(auto_attribs=True)
class PartialLabel:
    """
    Attributes:
        color (Union[Unset, str]):
        guideline (Union[Unset, str]):
        identifier (Union[Unset, str]):
        label (Union[Unset, str]):
        label_set_name (Union[Unset, str]):
        name (Union[Unset, str]):
    """

    color: Union[Unset, str] = UNSET
    guideline: Union[Unset, str] = UNSET
    identifier: Union[Unset, str] = UNSET
    label: Union[Unset, str] = UNSET
    label_set_name: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        color = self.color
        guideline = self.guideline
        identifier = self.identifier
        label = self.label
        label_set_name = self.label_set_name
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if color is not UNSET:
            field_dict["color"] = color
        if guideline is not UNSET:
            field_dict["guideline"] = guideline
        if identifier is not UNSET:
            field_dict["identifier"] = identifier
        if label is not UNSET:
            field_dict["label"] = label
        if label_set_name is not UNSET:
            field_dict["labelSetName"] = label_set_name
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        color = d.pop("color", UNSET)

        guideline = d.pop("guideline", UNSET)

        identifier = d.pop("identifier", UNSET)

        label = d.pop("label", UNSET)

        label_set_name = d.pop("labelSetName", UNSET)

        name = d.pop("name", UNSET)

        partial_label = cls(
            color=color,
            guideline=guideline,
            identifier=identifier,
            label=label,
            label_set_name=label_set_name,
            name=name,
        )

        return partial_label



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.annotate_binary_with_project_multipart_data import AnnotateBinaryWithProjectMultipartData
from ...models.annotated_document import AnnotatedDocument
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    client: Client,
    multipart_data: AnnotateBinaryWithProjectMultipartData,
    inline_labels: Union[Unset, None, bool] = True,
    inline_label_ids: Union[Unset, None, bool] = True,
    inline_text: Union[Unset, None, bool] = True,
    debug: Union[Unset, None, bool] = False,
    parallelize: Union[Unset, None, bool] = False,
    output_fields: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/annotate/projects/{projectName}/_annotate_binary".format(client.base_url, projectName=project_name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["inlineLabels"] = inline_labels

    params["inlineLabelIds"] = inline_label_ids

    params["inlineText"] = inline_text

    params["debug"] = debug

    params["parallelize"] = parallelize

    params["outputFields"] = output_fields

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    multipart_multipart_data = multipart_data.to_multipart()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "files": multipart_multipart_data,
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["AnnotatedDocument"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_annotated_document_array_item_data in _response_200:
            componentsschemas_annotated_document_array_item = AnnotatedDocument.from_dict(
                componentsschemas_annotated_document_array_item_data
            )

            response_200.append(componentsschemas_annotated_document_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[List["AnnotatedDocument"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Client,
    multipart_data: AnnotateBinaryWithProjectMultipartData,
    inline_labels: Union[Unset, None, bool] = True,
    inline_label_ids: Union[Unset, None, bool] = True,
    inline_text: Union[Unset, None, bool] = True,
    debug: Union[Unset, None, bool] = False,
    parallelize: Union[Unset, None, bool] = False,
    output_fields: Union[Unset, None, str] = UNSET,
) -> Response[List["AnnotatedDocument"]]:
    """annotate a binary document with the default annotator of the project

    Args:
        project_name (str):
        inline_labels (Union[Unset, None, bool]):  Default: True.
        inline_label_ids (Union[Unset, None, bool]):  Default: True.
        inline_text (Union[Unset, None, bool]):  Default: True.
        debug (Union[Unset, None, bool]):
        parallelize (Union[Unset, None, bool]):
        output_fields (Union[Unset, None, str]):
        multipart_data (AnnotateBinaryWithProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['AnnotatedDocument']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        multipart_data=multipart_data,
        inline_labels=inline_labels,
        inline_label_ids=inline_label_ids,
        inline_text=inline_text,
        debug=debug,
        parallelize=parallelize,
        output_fields=output_fields,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Client,
    multipart_data: AnnotateBinaryWithProjectMultipartData,
    inline_labels: Union[Unset, None, bool] = True,
    inline_label_ids: Union[Unset, None, bool] = True,
    inline_text: Union[Unset, None, bool] = True,
    debug: Union[Unset, None, bool] = False,
    parallelize: Union[Unset, None, bool] = False,
    output_fields: Union[Unset, None, str] = UNSET,
) -> Optional[List["AnnotatedDocument"]]:
    """annotate a binary document with the default annotator of the project

    Args:
        project_name (str):
        inline_labels (Union[Unset, None, bool]):  Default: True.
        inline_label_ids (Union[Unset, None, bool]):  Default: True.
        inline_text (Union[Unset, None, bool]):  Default: True.
        debug (Union[Unset, None, bool]):
        parallelize (Union[Unset, None, bool]):
        output_fields (Union[Unset, None, str]):
        multipart_data (AnnotateBinaryWithProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['AnnotatedDocument']]
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        multipart_data=multipart_data,
        inline_labels=inline_labels,
        inline_label_ids=inline_label_ids,
        inline_text=inline_text,
        debug=debug,
        parallelize=parallelize,
        output_fields=output_fields,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Client,
    multipart_data: AnnotateBinaryWithProjectMultipartData,
    inline_labels: Union[Unset, None, bool] = True,
    inline_label_ids: Union[Unset, None, bool] = True,
    inline_text: Union[Unset, None, bool] = True,
    debug: Union[Unset, None, bool] = False,
    parallelize: Union[Unset, None, bool] = False,
    output_fields: Union[Unset, None, str] = UNSET,
) -> Response[List["AnnotatedDocument"]]:
    """annotate a binary document with the default annotator of the project

    Args:
        project_name (str):
        inline_labels (Union[Unset, None, bool]):  Default: True.
        inline_label_ids (Union[Unset, None, bool]):  Default: True.
        inline_text (Union[Unset, None, bool]):  Default: True.
        debug (Union[Unset, None, bool]):
        parallelize (Union[Unset, None, bool]):
        output_fields (Union[Unset, None, str]):
        multipart_data (AnnotateBinaryWithProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['AnnotatedDocument']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        multipart_data=multipart_data,
        inline_labels=inline_labels,
        inline_label_ids=inline_label_ids,
        inline_text=inline_text,
        debug=debug,
        parallelize=parallelize,
        output_fields=output_fields,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Client,
    multipart_data: AnnotateBinaryWithProjectMultipartData,
    inline_labels: Union[Unset, None, bool] = True,
    inline_label_ids: Union[Unset, None, bool] = True,
    inline_text: Union[Unset, None, bool] = True,
    debug: Union[Unset, None, bool] = False,
    parallelize: Union[Unset, None, bool] = False,
    output_fields: Union[Unset, None, str] = UNSET,
) -> Optional[List["AnnotatedDocument"]]:
    """annotate a binary document with the default annotator of the project

    Args:
        project_name (str):
        inline_labels (Union[Unset, None, bool]):  Default: True.
        inline_label_ids (Union[Unset, None, bool]):  Default: True.
        inline_text (Union[Unset, None, bool]):  Default: True.
        debug (Union[Unset, None, bool]):
        parallelize (Union[Unset, None, bool]):
        output_fields (Union[Unset, None, str]):
        multipart_data (AnnotateBinaryWithProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['AnnotatedDocument']]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            multipart_data=multipart_data,
            inline_labels=inline_labels,
            inline_label_ids=inline_label_ids,
            inline_text=inline_text,
            debug=debug,
            parallelize=parallelize,
            output_fields=output_fields,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.project_annotators import ProjectAnnotators


T = TypeVar("T", bound="ProjectsAnnotators")


@attr.s(auto_attribs=True)
class ProjectsAnnotators:
    """
    Attributes:
        annotators (ProjectAnnotators):
        project_name (str):
    """

    annotators: "ProjectAnnotators"
    project_name: str

    def to_dict(self) -> Dict[str, Any]:
        annotators = self.annotators.to_dict()

        project_name = self.project_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "annotators": annotators,
                "projectName": project_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.project_annotators import ProjectAnnotators

        d = src_dict.copy()
        annotators = ProjectAnnotators.from_dict(d.pop("annotators"))

        project_name = d.pop("projectName")

        projects_annotators = cls(
            annotators=annotators,
            project_name=project_name,
        )

        return projects_annotators



from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.project_property import ProjectProperty
from ...types import Response


def _get_kwargs(
    project_name: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/projects/{projectName}/properties".format(client.base_url, projectName=project_name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ProjectProperty]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ProjectProperty.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[ProjectProperty]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Client,
) -> Response[ProjectProperty]:
    """get the properties of the project

    Args:
        project_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ProjectProperty]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Client,
) -> Optional[ProjectProperty]:
    """get the properties of the project

    Args:
        project_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ProjectProperty]
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Client,
) -> Response[ProjectProperty]:
    """get the properties of the project

    Args:
        project_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ProjectProperty]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Client,
) -> Optional[ProjectProperty]:
    """get the properties of the project

    Args:
        project_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ProjectProperty]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
        )
    ).parsed



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="QualityFigures")


@attr.s(auto_attribs=True)
class QualityFigures:
    """
    Attributes:
        f1 (float):
        precision (float):
        recall (float):
        support (int):
        roc_auc (Union[Unset, float]):
    """

    f1: float
    precision: float
    recall: float
    support: int
    roc_auc: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        f1 = self.f1
        precision = self.precision
        recall = self.recall
        support = self.support
        roc_auc = self.roc_auc

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "f1": f1,
                "precision": precision,
                "recall": recall,
                "support": support,
            }
        )
        if roc_auc is not UNSET:
            field_dict["roc_auc"] = roc_auc

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        f1 = d.pop("f1")

        precision = d.pop("precision")

        recall = d.pop("recall")

        support = d.pop("support")

        roc_auc = d.pop("roc_auc", UNSET)

        quality_figures = cls(
            f1=f1,
            precision=precision,
            recall=recall,
            support=support,
            roc_auc=roc_auc,
        )

        return quality_figures



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, cast

import attr

if TYPE_CHECKING:
    from ..models.engine_config import EngineConfig
    from ..models.model_metrics_options import ModelMetricsOptions
    from ..models.report import Report


T = TypeVar("T", bound="ModelMetrics")


@attr.s(auto_attribs=True)
class ModelMetrics:
    """
    Attributes:
        classes (List[str]):
        config (EngineConfig):
        engine (str):
        lang (str):
        name (str):
        options (ModelMetricsOptions):
        quality (float):
        report (Report):
        status (str):
        timestamp (int):
        timestamp_end (int):
    """

    classes: List[str]
    config: "EngineConfig"
    engine: str
    lang: str
    name: str
    options: "ModelMetricsOptions"
    quality: float
    report: "Report"
    status: str
    timestamp: int
    timestamp_end: int

    def to_dict(self) -> Dict[str, Any]:
        classes = self.classes

        config = self.config.to_dict()

        engine = self.engine
        lang = self.lang
        name = self.name
        options = self.options.to_dict()

        quality = self.quality
        report = self.report.to_dict()

        status = self.status
        timestamp = self.timestamp
        timestamp_end = self.timestamp_end

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "classes": classes,
                "config": config,
                "engine": engine,
                "lang": lang,
                "name": name,
                "options": options,
                "quality": quality,
                "report": report,
                "status": status,
                "timestamp": timestamp,
                "timestamp_end": timestamp_end,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.engine_config import EngineConfig
        from ..models.model_metrics_options import ModelMetricsOptions
        from ..models.report import Report

        d = src_dict.copy()
        classes = cast(List[str], d.pop("classes"))

        config = EngineConfig.from_dict(d.pop("config"))

        engine = d.pop("engine")

        lang = d.pop("lang")

        name = d.pop("name")

        options = ModelMetricsOptions.from_dict(d.pop("options"))

        quality = d.pop("quality")

        report = Report.from_dict(d.pop("report"))

        status = d.pop("status")

        timestamp = d.pop("timestamp")

        timestamp_end = d.pop("timestamp_end")

        model_metrics = cls(
            classes=classes,
            config=config,
            engine=engine,
            lang=lang,
            name=name,
            options=options,
            quality=quality,
            report=report,
            status=status,
            timestamp=timestamp,
            timestamp_end=timestamp_end,
        )

        return model_metrics



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.formatter_parameters import FormatterParameters


T = TypeVar("T", bound="Formatter")


@attr.s(auto_attribs=True)
class Formatter:
    """
    Attributes:
        name (str): Name of the formatter (e.g. tabular)
        parameters (Union[Unset, FormatterParameters]): Optional formatting parameters
    """

    name: str
    parameters: Union[Unset, "FormatterParameters"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
            }
        )
        if parameters is not UNSET:
            field_dict["parameters"] = parameters

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.formatter_parameters import FormatterParameters

        d = src_dict.copy()
        name = d.pop("name")

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, FormatterParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = FormatterParameters.from_dict(_parameters)

        formatter = cls(
            name=name,
            parameters=parameters,
        )

        return formatter



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.document_facets import DocumentFacets


T = TypeVar("T", bound="CorpusMetrics")


@attr.s(auto_attribs=True)
class CorpusMetrics:
    """
    Attributes:
        corpus_size (int):
        document_count (int):
        document_facets (DocumentFacets):
        segment_count (int):
    """

    corpus_size: int
    document_count: int
    document_facets: "DocumentFacets"
    segment_count: int

    def to_dict(self) -> Dict[str, Any]:
        corpus_size = self.corpus_size
        document_count = self.document_count
        document_facets = self.document_facets.to_dict()

        segment_count = self.segment_count

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "corpusSize": corpus_size,
                "documentCount": document_count,
                "documentFacets": document_facets,
                "segmentCount": segment_count,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.document_facets import DocumentFacets

        d = src_dict.copy()
        corpus_size = d.pop("corpusSize")

        document_count = d.pop("documentCount")

        document_facets = DocumentFacets.from_dict(d.pop("documentFacets"))

        segment_count = d.pop("segmentCount")

        corpus_metrics = cls(
            corpus_size=corpus_size,
            document_count=document_count,
            document_facets=document_facets,
            segment_count=segment_count,
        )

        return corpus_metrics



from typing import Any, Dict, Type, TypeVar

import attr

T = TypeVar("T", bound="AnnotatedDocAltText")


@attr.s(auto_attribs=True)
class AnnotatedDocAltText:
    """A document alternative text

    Attributes:
        name (str): The alternative text name
        text (str): The alternative text
    """

    name: str
    text: str

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        text = self.text

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
                "text": text,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        text = d.pop("text")

        annotated_doc_alt_text = cls(
            name=name,
            text=text,
        )

        return annotated_doc_alt_text



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.new_suggester_parameters import NewSuggesterParameters


T = TypeVar("T", bound="NewSuggester")


@attr.s(auto_attribs=True)
class NewSuggester:
    """
    Attributes:
        engine (str):
        label (str):
        parameters (NewSuggesterParameters):
        tags (Union[Unset, List[str]]):
    """

    engine: str
    label: str
    parameters: "NewSuggesterParameters"
    tags: Union[Unset, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        engine = self.engine
        label = self.label
        parameters = self.parameters.to_dict()

        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "engine": engine,
                "label": label,
                "parameters": parameters,
            }
        )
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.new_suggester_parameters import NewSuggesterParameters

        d = src_dict.copy()
        engine = d.pop("engine")

        label = d.pop("label")

        parameters = NewSuggesterParameters.from_dict(d.pop("parameters"))

        tags = cast(List[str], d.pop("tags", UNSET))

        new_suggester = cls(
            engine=engine,
            label=label,
            parameters=parameters,
            tags=tags,
        )

        return new_suggester



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="NewUser")


@attr.s(auto_attribs=True)
class NewUser:
    """
    Attributes:
        password (str):
        permissions (List[str]):
        roles (List[str]):
        username (str):
        email (Union[Unset, str]):
    """

    password: str
    permissions: List[str]
    roles: List[str]
    username: str
    email: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        password = self.password
        permissions = self.permissions

        roles = self.roles

        username = self.username
        email = self.email

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "password": password,
                "permissions": permissions,
                "roles": roles,
                "username": username,
            }
        )
        if email is not UNSET:
            field_dict["email"] = email

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        password = d.pop("password")

        permissions = cast(List[str], d.pop("permissions"))

        roles = cast(List[str], d.pop("roles"))

        username = d.pop("username")

        email = d.pop("email", UNSET)

        new_user = cls(
            password=password,
            permissions=permissions,
            roles=roles,
            username=username,
            email=email,
        )

        return new_user



from typing import Any, Dict, Type, TypeVar

import attr

from ..models.search_total_relation import SearchTotalRelation

T = TypeVar("T", bound="SearchTotal")


@attr.s(auto_attribs=True)
class SearchTotal:
    """
    Attributes:
        relation (SearchTotalRelation):
        value (int):
    """

    relation: SearchTotalRelation
    value: int

    def to_dict(self) -> Dict[str, Any]:
        relation = self.relation.value

        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "relation": relation,
                "value": value,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        relation = SearchTotalRelation(d.pop("relation"))

        value = d.pop("value")

        search_total = cls(
            relation=relation,
            value=value,
        )

        return search_total



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.document import Document


T = TypeVar("T", bound="DocumentHit")


@attr.s(auto_attribs=True)
class DocumentHit:
    """
    Attributes:
        id (str):
        document (Document):
        score (float):
    """

    id: str
    document: "Document"
    score: float

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        document = self.document.to_dict()

        score = self.score

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "_id": id,
                "document": document,
                "score": score,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.document import Document

        d = src_dict.copy()
        id = d.pop("_id")

        document = Document.from_dict(d.pop("document"))

        score = d.pop("score")

        document_hit = cls(
            id=id,
            document=document,
            score=score,
        )

        return document_hit



from typing import Any, Dict, Type, TypeVar

import attr

T = TypeVar("T", bound="MetadataCount")


@attr.s(auto_attribs=True)
class MetadataCount:
    """
    Attributes:
        id (str):
        document_count (int):
        segment_count (int):
    """

    id: str
    document_count: int
    segment_count: int

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        document_count = self.document_count
        segment_count = self.segment_count

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "_id": id,
                "documentCount": document_count,
                "segmentCount": segment_count,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("_id")

        document_count = d.pop("documentCount")

        segment_count = d.pop("segmentCount")

        metadata_count = cls(
            id=id,
            document_count=document_count,
            segment_count=segment_count,
        )

        return metadata_count



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.metadata_count import MetadataCount


T = TypeVar("T", bound="DocumentFacets")


@attr.s(auto_attribs=True)
class DocumentFacets:
    """
    Attributes:
        facets (List['MetadataCount']):
        metadata (str):
    """

    facets: List["MetadataCount"]
    metadata: str

    def to_dict(self) -> Dict[str, Any]:
        facets = []
        for facets_item_data in self.facets:
            facets_item = facets_item_data.to_dict()

            facets.append(facets_item)

        metadata = self.metadata

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "facets": facets,
                "metadata": metadata,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.metadata_count import MetadataCount

        d = src_dict.copy()
        facets = []
        _facets = d.pop("facets")
        for facets_item_data in _facets:
            facets_item = MetadataCount.from_dict(facets_item_data)

            facets.append(facets_item)

        metadata = d.pop("metadata")

        document_facets = cls(
            facets=facets,
            metadata=metadata,
        )

        return document_facets
